@@ -23,18 +23,14 @@
  ***************************************************************************/
 #include "tool_setup.h"
 
-#ifdef _WIN32
-#include <direct.h>
-#endif
-
 #include "tool_dirhie.h"
 #include "tool_msgs.h"
 
-#if defined(_WIN32) || (defined(MSDOS) && !defined(__DJGPP__))
-#  define mkdir(x,y) (mkdir)((x))
-#  ifndef F_OK
-#  define F_OK 0
-#  endif
+#ifdef _WIN32
+#  include <direct.h>
+#  define mkdir(x, y) _mkdir(x)
+#elif defined(MSDOS) && !defined(__DJGPP__)
+#  define mkdir(x, y) (mkdir)(x)
 #endif
 
 static void show_dir_errno(const char *name)
@@ -112,7 +108,7 @@ CURLcode create_dir_hierarchy(const char *outfile)
          exist, since we would be creating it erroneously. eg if outfile is
          X:\foo\bar\filename then do not mkdir X: This logic takes into
          account unsupported drives !:, 1:, etc. */
-      if(len > 1 && (outfile[1]==':'))
+      if(len > 1 && (outfile[1] == ':'))
         skip = TRUE;
     }
 #endif
